"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.endLoadingMessage = exports.startLoadingMessage = exports.showCursor = exports.hideCursor = exports.clear = exports.printErrorMessage = exports.printSuccessMessage = exports.printInfoMessage = exports.setTextWidth = exports.makeDimText = exports.makeRedText = exports.makeBlueText = exports.makeGreenText = exports.print = exports.runProgram = exports.addCommand = void 0;
var commander_1 = require("commander");
function addCommand(config) {
    var cm = commander_1.program
        .command(config.command)
        .description(config.description || '')
        .action(function (flags) { return config.action(flags); });
    config.flags.forEach(function (flag) {
        cm.option(flag.flag + ' <value>', flag.description || '', flag.default);
    });
}
exports.addCommand = addCommand;
function runProgram() {
    commander_1.program.parse();
}
exports.runProgram = runProgram;
var ANSI_PREFIX = '\x1b[';
var HIDE_CURSOR = ANSI_PREFIX + '?25l';
var SHOW_CURSOR = ANSI_PREFIX + '?25h';
var MOVE_CURSOR_TO_NEXT_LINE = ANSI_PREFIX + '1G';
var GREEN_TEXT = ANSI_PREFIX + '32m';
var BLUE_TEXT = ANSI_PREFIX + '34m';
var AQUA_TEXT = ANSI_PREFIX + '36m';
var WHITE_TEXT = ANSI_PREFIX + '37m';
var RED_TEXT = ANSI_PREFIX + '31m';
var DIM_TEXT = ANSI_PREFIX + '2m';
var BRIGHT_TEXT = ANSI_PREFIX + '0m';
function print(text) {
    console.log(text);
}
exports.print = print;
function makeGreenText(x) {
    return "".concat(GREEN_TEXT).concat(x).concat(WHITE_TEXT);
}
exports.makeGreenText = makeGreenText;
function makeBlueText(x) {
    return "".concat(BLUE_TEXT).concat(x).concat(WHITE_TEXT);
}
exports.makeBlueText = makeBlueText;
function makeRedText(x) {
    return "".concat(RED_TEXT).concat(x).concat(WHITE_TEXT);
}
exports.makeRedText = makeRedText;
function makeDimText(text) {
    return "".concat(DIM_TEXT).concat(text).concat(BRIGHT_TEXT);
}
exports.makeDimText = makeDimText;
function setTextWidth(text, length) {
    return text.padEnd(length, ' ');
}
exports.setTextWidth = setTextWidth;
function printInfoMessage(text) {
    print(text);
}
exports.printInfoMessage = printInfoMessage;
function printSuccessMessage(text) {
    print(makeGreenText(text));
}
exports.printSuccessMessage = printSuccessMessage;
function printErrorMessage(text) {
    print(makeRedText(text));
}
exports.printErrorMessage = printErrorMessage;
function clear() {
    console.clear();
}
exports.clear = clear;
function hideCursor() {
    print(HIDE_CURSOR);
}
exports.hideCursor = hideCursor;
function showCursor() {
    print(SHOW_CURSOR);
}
exports.showCursor = showCursor;
var loadingInterval;
function startLoadingMessage(text) {
    var process = require('process');
    if (!process.stdout.isTTY) {
        console.log(text);
        return;
    }
    var std = process.stdout;
    var dots = ['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏'];
    var spinnerFrames = dots;
    var index = 0;
    var log = function () {
        var line = spinnerFrames[index];
        if (!line) {
            index = 0;
            line = spinnerFrames[index];
        }
        process.stdout.clearLine();
        process.stdout.cursorTo(0);
        std.write(AQUA_TEXT + line + WHITE_TEXT + ' ' + text);
        index = index >= spinnerFrames.length ? 0 : index + 1;
    };
    clearInterval(loadingInterval);
    log();
    loadingInterval = setInterval(log, 100);
}
exports.startLoadingMessage = startLoadingMessage;
function endLoadingMessage() {
    clearInterval(loadingInterval);
}
exports.endLoadingMessage = endLoadingMessage;
